.. _bundled-extensions:

Bundled extensions
******************

Media Tree contains a few useful extensions in its ``contrib`` module. Since
some of these extensions modify the ``FileNode`` model, you should install them
before you run ``syncdb`` for the first time.

.. automodule:: media_tree.contrib.media_extensions.images.focal_point
   :members:
   :inherited-members:

.. automodule:: media_tree.contrib.media_extensions.zipfiles
   :members:
   :inherited-members:
